import { EventEmitter, OnChanges, OnInit, SimpleChanges, TemplateRef } from '@angular/core';
import { FormControl } from '@angular/forms';
import { DataTableColumn, DataTableColumnFormatType, FetchRecordsEvent } from './data-table.model';
import * as i0 from "@angular/core";
export declare class DataTableComponent implements OnInit, OnChanges {
    columns: DataTableColumn[];
    records: any[];
    displaySizeOptions: any;
    totalRecordsCount: number;
    pageSize: number;
    label: string;
    loading: boolean;
    /**
     *
     * @description TemplateRef passed by name from parent component
     *
     * @param record Required \<ng-template\> attribute: let-record=record
     * @param column Optional \<ng-template\> attribute: let-column=column. Useful in case of multiple custom columns with 'templateRef' format type.
     *
     * @example
     * ```html
     * <ng-template #templateRefName
     *     let-column="column"
     *     let-record="record">
     *   <ng-container *ngIf="column.field === 'myColumnFieldName'">
     *     {{record.fleet.name}}
     *   </ng-container>
     * </ng-template>
     * ```
     */
    customCellTemplateRef?: TemplateRef<void>;
    fetchRecords: EventEmitter<FetchRecordsEvent>;
    readonly dataTableColumnFormatType: typeof DataTableColumnFormatType;
    readonly PAGE_SIZE_OPTIONS: any;
    currentPageIndex: number;
    currentPageStart: number;
    currentPageEnd: number;
    searchControl: FormControl;
    sortedColumn: DataTableColumn | undefined;
    constructor();
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    reset(): void;
    clearSearch(): void;
    onPageSizeChanged(size: number): void;
    onPageIndexChanged(pageIndex: number): void;
    private _subscribeToSearchControlChanges;
    private _resetPagination;
    private _fetchRecords;
    private _setPaginationStartAndEnd;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataTableComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DataTableComponent, "x-data-table", never, { "columns": "columns"; "records": "records"; "displaySizeOptions": "displaySizeOptions"; "totalRecordsCount": "totalRecordsCount"; "pageSize": "pageSize"; "label": "label"; "loading": "loading"; "customCellTemplateRef": "customCellTemplateRef"; }, { "fetchRecords": "fetchRecords"; }, never, never>;
}
